# UltrastarParser

Contains methods to read or edit ultrastar files or directories.

Not yet implemented:

- Adding new tags to files
- Removing tags from files
- Auto-detecting duet
- Auto-detecting missing information including files, previewstart, language, genre
